/** A simple dynamically-typed language that smacks of Python.
 *  This builds a tree, then we'll interpret it with a tree grammar
 *  Build a convential symbol table while parsing.  Save
 *  symbol ptrs in AST nodes.
 */
grammar LDDsl;
options {output=AST; ASTLabelType=LDDslAST;}

tokens {
	ARGS; FIELDS; PROGRAM; FUNCTION; BLOCK; VAR; CALL; MCALL; LIST; DICT; PAIRE; 
	IF='if'; ELSEIF='elseif'; WHILE='while'; RRETURN='return'; DEF='def'; 
	ASSIGN='='; ADD='+'; SUB='-'; MUL='*'; DIV='/'; 
	EQ='=='; NE='!='; LTT='<'; LE='<='; GT='>';GE='>='; 
	OR='||'; AND='&&'; NG='!';
	STRUCT='struct'; DOT='.'; NEW='new';BREAK='break';
	}

program
	:	(structDefinition|functionDefinition|statement)* EOF 
		-> ^(PROGRAM structDefinition* functionDefinition* statement*)
	;
	
structDefinition
    :   'struct' ID '{' 
		(vardef ';')* '}'
		-> ^(STRUCT ID vardef*)
    ;

functionDefinition
	:	'def' ID 
        '(' args ')'
		slist
		-> ^(FUNCTION ID args slist)
	;

args : (ID (',' ID)* )?
	   -> ^(ARGS ID*)
	 ;

slist
	:	'{' statement* '}'	-> ^(BLOCK statement*)
	;

statement
	:   vardef ';'                   -> vardef
	|	qid '=' expr ';'				-> ^('=' qid expr)
	|	'return' expr ';'  			-> ^('return' expr)
	|	'if' '(' expr ')' c=slist elseif* ('else' el=slist)? -> ^('if' expr $c elseif* $el?)
	|	'while' '(' expr ')' slist			-> ^('while' expr slist)
	|	call ';'						-> call
	|   mcall ';'   -> mcall
	|	'break' ';' -> ^('break')
	;

elseif 
	: 'elseif' '(' expr ')' slist  -> ^('elseif' expr slist) 
	;

call
	:	name=ID '(' (expr (',' expr )*)? ')' -> ^(CALL ID expr*) ;

mcall : name=ID '.' func=ID '(' (expr (',' expr )*)? ')' -> ^(MCALL $name $func expr*);

expr:	ngexpr (('||'|'&&')^ ngexpr)*
		;

ngexpr : cmpexpr
	   | ('!'^ cmpexpr)
	   ;
	   
cmpexpr
	:  addexpr (('=='|'<'|'>'|'>='|'<='|'!=')^ addexpr)? ;

addexpr
	:	mulexpr (('+'|'-')^ mulexpr)*
	;

mulexpr 
	:	signexpr (('*'|'/')^ signexpr)*
	;

signexpr 
	: atom
	| '+' atom -> ^('+' atom)
	| '-' atom -> ^('-' atom)
	;

atom 
	:	NNULL
	|   LONG		        
	|	DOUBLE	    
	|	STRING	    
	|	qid		    
	|	call
	|   mcall
	|	instance
	|   list
	|   dict
	|	'(' expr ')' -> expr
	;

instance
	:	'new' sname=ID
		-> ^('new' ID)
	;

qid :	ID ('.'^ ID)* ;  // CAN'T RESOLVE TIL RUNTIME!

list :  '@[' (expr (',' expr)* )? ']' 
	     -> ^(LIST expr*)
	 ;

dict : '@{' (pair (',' pair)*)?'}'
		-> ^(DICT pair*)
		;

pair : expr ':' expr	
	   -> ^(PAIRE expr expr)
	   ;

vardef
	:	'var' ID ('=' expr)?
	-> ^(VAR ID expr?)
	;

// L e x i c a l  R u l e s
NNULL : 'null' ;

ID  :   LETTER (LETTER | '0'..'9' | '_')*  ;

fragment
LETTER
	:   ('a'..'z' | 'A'..'Z')
    ;


STRING:	('\"' .* '\"') | ('\''.*'\'');

LONG :   '0'..'9'+ ;
    
DOUBLE
	:	LONG '.' LONG*
	|	'.' LONG+
	;

WS  :   (' '|'\t'|'\r'|'\n') {$channel=HIDDEN;} ;

SL_COMMENT
    :  
    ('//' ~('\r'|'\n')* ) {$channel=HIDDEN;} 
    | ('/*'.*'*/') {$channel=HIDDEN;}

    ;