if (typeof JSON !== "object") {
    JSON = {};
}

(function () {
    "use strict";

    var rx_one = /^[\],:{}\s]*$/;
    var rx_two = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g;
    var rx_three = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g;
    var rx_four = /(?:^|:|,)(?:\s*\[)+/g;
    var rx_escapable = /[\\"\u0000-\u001f\u007f-\u009f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;
    var rx_dangerous = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;

    function f(n) {
        // Format integers to have at least two digits.
        return n < 10
            ? "0" + n
            : n;
    }

    function this_value() {
        return this.valueOf();
    }

    if (typeof Date.prototype.toJSON !== "function") {

        Date.prototype.toJSON = function () {

            return isFinite(this.valueOf())
                ? this.getUTCFullYear() + "-" +
                f(this.getUTCMonth() + 1) + "-" +
                f(this.getUTCDate()) + "T" +
                f(this.getUTCHours()) + ":" +
                f(this.getUTCMinutes()) + ":" +
                f(this.getUTCSeconds()) + "Z"
                : null;
        };

        Boolean.prototype.toJSON = this_value;
        Number.prototype.toJSON = this_value;
        String.prototype.toJSON = this_value;
    }

    var gap;
    var indent;
    var meta;
    var rep;


    function quote(string) {

// If the string contains no control characters, no quote characters, and no
// backslash characters, then we can safely slap some quotes around it.
// Otherwise we must also replace the offending characters with safe escape
// sequences.

        rx_escapable.lastIndex = 0;
        return rx_escapable.test(string)
            ? "\"" + string.replace(rx_escapable, function (a) {
                var c = meta[a];
                return typeof c === "string"
                    ? c
                    : "\\u" + ("0000" + a.charCodeAt(0).toString(16)).slice(-4);
            }) + "\""
            : "\"" + string + "\"";
    }


    function str(key, holder) {

// Produce a string from holder[key].

        var i;          // The loop counter.
        var k;          // The member key.
        var v;          // The member value.
        var length;
        var mind = gap;
        var partial;
        var value = holder[key];

// If the value has a toJSON method, call it to obtain a replacement value.

        if (value && typeof value === "object" &&
            typeof value.toJSON === "function") {
            value = value.toJSON(key);
        }

// If we were called with a replacer function, then call the replacer to
// obtain a replacement value.

        if (typeof rep === "function") {
            value = rep.call(holder, key, value);
        }

// What happens next depends on the value's type.

        switch (typeof value) {
            case "string":
                return quote(value);

            case "number":

// JSON numbers must be finite. Encode non-finite numbers as null.

                return isFinite(value)
                    ? String(value)
                    : "null";

            case "boolean":
            case "null":

// If the value is a boolean or null, convert it to a string. Note:
// typeof null does not produce "null". The case is included here in
// the remote chance that this gets fixed someday.

                return String(value);

// If the type is "object", we might be dealing with an object or an array or
// null.

            case "object":

// Due to a specification blunder in ECMAScript, typeof null is "object",
// so watch out for that case.

                if (!value) {
                    return "null";
                }

// Make an array to hold the partial results of stringifying this object value.

                gap += indent;
                partial = [];

// Is the value an array?

                if (Object.prototype.toString.apply(value) === "[object Array]") {

// The value is an array. Stringify every element. Use null as a placeholder
// for non-JSON values.

                    length = value.length;
                    for (i = 0; i < length; i += 1) {
                        partial[i] = str(i, value) || "null";
                    }

// Join all of the elements together, separated with commas, and wrap them in
// brackets.

                    v = partial.length === 0
                        ? "[]"
                        : gap
                            ? "[\n" + gap + partial.join(",\n" + gap) + "\n" + mind + "]"
                            : "[" + partial.join(",") + "]";
                    gap = mind;
                    return v;
                }

// If the replacer is an array, use it to select the members to be stringified.

                if (rep && typeof rep === "object") {
                    length = rep.length;
                    for (i = 0; i < length; i += 1) {
                        if (typeof rep[i] === "string") {
                            k = rep[i];
                            v = str(k, value);
                            if (v) {
                                partial.push(quote(k) + (
                                        gap
                                            ? ": "
                                            : ":"
                                    ) + v);
                            }
                        }
                    }
                } else {

// Otherwise, iterate through all of the keys in the object.

                    for (k in value) {
                        if (Object.prototype.hasOwnProperty.call(value, k)) {
                            v = str(k, value);
                            if (v) {
                                partial.push(quote(k) + (
                                        gap
                                            ? ": "
                                            : ":"
                                    ) + v);
                            }
                        }
                    }
                }

// Join all of the member texts together, separated with commas,
// and wrap them in braces.

                v = partial.length === 0
                    ? "{}"
                    : gap
                        ? "{\n" + gap + partial.join(",\n" + gap) + "\n" + mind + "}"
                        : "{" + partial.join(",") + "}";
                gap = mind;
                return v;
        }
    }

// If the JSON object does not yet have a stringify method, give it one.

    if (typeof JSON.stringify !== "function") {
        meta = {    // table of character substitutions
            "\b": "\\b",
            "\t": "\\t",
            "\n": "\\n",
            "\f": "\\f",
            "\r": "\\r",
            "\"": "\\\"",
            "\\": "\\\\"
        };
        JSON.stringify = function (value, replacer, space) {

// The stringify method takes a value and an optional replacer, and an optional
// space parameter, and returns a JSON text. The replacer can be a function
// that can replace values, or an array of strings that will select the keys.
// A default replacer method can be provided. Use of the space parameter can
// produce text that is more easily readable.

            var i;
            gap = "";
            indent = "";

// If the space parameter is a number, make an indent string containing that
// many spaces.

            if (typeof space === "number") {
                for (i = 0; i < space; i += 1) {
                    indent += " ";
                }

// If the space parameter is a string, it will be used as the indent string.

            } else if (typeof space === "string") {
                indent = space;
            }

// If there is a replacer, it must be a function or an array.
// Otherwise, throw an error.

            rep = replacer;
            if (replacer && typeof replacer !== "function" &&
                (typeof replacer !== "object" ||
                typeof replacer.length !== "number")) {
                throw new Error("JSON.stringify");
            }

// Make a fake root object containing our value under the key of "".
// Return the result of stringifying the value.

            return str("", {"": value});
        };
    }


// If the JSON object does not yet have a parse method, give it one.

    if (typeof JSON.parse !== "function") {
        JSON.parse = function (text, reviver) {

// The parse method takes a text and an optional reviver function, and returns
// a JavaScript value if the text is a valid JSON text.

            var j;

            function walk(holder, key) {

// The walk method is used to recursively walk the resulting structure so
// that modifications can be made.

                var k;
                var v;
                var value = holder[key];
                if (value && typeof value === "object") {
                    for (k in value) {
                        if (Object.prototype.hasOwnProperty.call(value, k)) {
                            v = walk(value, k);
                            if (v !== undefined) {
                                value[k] = v;
                            } else {
                                delete value[k];
                            }
                        }
                    }
                }
                return reviver.call(holder, key, value);
            }


// Parsing happens in four stages. In the first stage, we replace certain
// Unicode characters with escape sequences. JavaScript handles many characters
// incorrectly, either silently deleting them, or treating them as line endings.

            text = String(text);
            rx_dangerous.lastIndex = 0;
            if (rx_dangerous.test(text)) {
                text = text.replace(rx_dangerous, function (a) {
                    return "\\u" +
                        ("0000" + a.charCodeAt(0).toString(16)).slice(-4);
                });
            }

// In the second stage, we run the text against regular expressions that look
// for non-JSON patterns. We are especially concerned with "()" and "new"
// because they can cause invocation, and "=" because it can cause mutation.
// But just to be safe, we want to reject all unexpected forms.

// We split the second stage into 4 regexp operations in order to work around
// crippling inefficiencies in IE's and Safari's regexp engines. First we
// replace the JSON backslash pairs with "@" (a non-JSON character). Second, we
// replace all simple value tokens with "]" characters. Third, we delete all
// open brackets that follow a colon or comma or that begin the text. Finally,
// we look to see that the remaining characters are only whitespace or "]" or
// "," or ":" or "{" or "}". If that is so, then the text is safe for eval.

            if (
                rx_one.test(
                    text
                        .replace(rx_two, "@")
                        .replace(rx_three, "]")
                        .replace(rx_four, "")
                )
            ) {

// In the third stage we use the eval function to compile the text into a
// JavaScript structure. The "{" operator is subject to a syntactic ambiguity
// in JavaScript: it can begin a block or an object literal. We wrap the text
// in parens to eliminate the ambiguity.

                j = eval("(" + text + ")");

// In the optional fourth stage, we recursively walk the new structure, passing
// each name/value pair to a reviver function for possible transformation.

                return (typeof reviver === "function")
                    ? walk({"": j}, "")
                    : j;
            }

// If the text is not JSON parseable, then a SyntaxError is thrown.

            throw new SyntaxError("JSON.parse");
        };
    }
}());

var ua =  navigator.userAgent,
    webkit = ua.match(/Web[kK]it[\/]{0,1}([\d.]+)/),
    android = ua.match(/(Android);?[\s\/]+([\d.]+)?/),
    osx = !!ua.match(/\(Macintosh\; Intel /),
    ipad = ua.match(/(iPad).*OS\s([\d_]+)/),
    ipod = ua.match(/(iPod)(.*OS\s([\d_]+))?/),
    iphone = !ipad && ua.match(/(iPhone\sOS)\s([\d_]+)/),
    webos = ua.match(/(webOS|hpwOS)[\s\/]([\d.]+)/),
    wp = ua.match(/Windows Phone ([\d.]+)/),
    touchpad = webos && ua.match(/TouchPad/),
    kindle = ua.match(/Kindle\/([\d.]+)/),
    silk = ua.match(/Silk\/([\d._]+)/),
    blackberry = ua.match(/(BlackBerry).*Version\/([\d.]+)/),
    bb10 = ua.match(/(BB10).*Version\/([\d.]+)/),
    rimtabletos = ua.match(/(RIM\sTablet\sOS)\s([\d.]+)/),
    playbook = ua.match(/PlayBook/),
    chrome = ua.match(/Chrome\/([\d.]+)/) || ua.match(/CriOS\/([\d.]+)/),
    firefox = ua.match(/Firefox\/([\d.]+)/),
    firefoxos = ua.match(/\((?:Mobile|Tablet); rv:([\d.]+)\).*Firefox\/[\d.]+/),
    ie = ua.match(/MSIE\s([\d.]+)/) || ua.match(/Trident\/[\d](?=[^\?]+).*rv:([0-9.].)/),
    webview = !chrome && ua.match(/(iPhone|iPod|iPad).*AppleWebKit(?!.*Safari)/),
    safari = webview || ua.match(/Version\/([\d.]+)([^S](Safari)|[^M]*(Mobile)[^S]*(Safari))/)

console.log("userAgent =======" + ua);
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//以下是业务代码
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function deviceCtxSession() {
    var sessionRandom = Math.floor((1 << 24) * Math.random());
    var sessionTimestamp = new Date().getTime();
    return sessionRandom + '' + sessionTimestamp;
}

function subString(str, start, end) {
    return str.substring(start,end);
}

function getTimeStr() {
    var serverTime = new Date();
    var time_str = serverTime.formatWithTimezone("yyyyMMddhhmmss", 8);
    return time_str;
}

function getTimeNow() {
    var time = new Date();
    return time.getTime() + '';
}

function timeLast(time, offset) {
    var now = new Date();
    var last = now.getTime() - time;
    if(last > offset) {
        return '1';
    }
    return '0';
}

function preDate(datestr) {
    var yesterday = Date.parse(datestr);
    var yesterday_milliseconds = yesterday.getTime() - 1000 * 60 * 60 * 24;
    yesterday.setTime(yesterday_milliseconds);

    var strYear = yesterday.getFullYear();
    var strDay = yesterday.getDate();
    var strMonth = yesterday.getMonth() + 1;
    if (strMonth < 10) {
        strMonth = "0" + strMonth;
    }
    datastr = strYear + "-" + strMonth + "-" + strDay;
    return datastr;
}

function getYestoday() {
    var yesterday = new Date();
    var yesterday_milliseconds = yesterday.getTime() - 1000 * 60 * 60 * 24;
    yesterday.setTime(yesterday_milliseconds);

    var strYear = yesterday.getFullYear();
    var strDay = yesterday.getDate();
    var strMonth = yesterday.getMonth() + 1;
    if (strMonth < 10) {
        strMonth = "0" + strMonth;
    }
    datastr = strYear + "-" + strMonth + "-" + strDay;
    return datastr;
}

function getTimeOffset(serverTime) {
    var d = new Date(serverTime);
    return Date.now() - d;
}

function getX() {
    return Math.random();
}

function getPassengerStatus(passenger_id_type_code, total_times) {
    var j = total_times;
    var h = "待核验";
    if (passenger_id_type_code == "2") {
        h = "未通过";
    } else {
        if (j == "95" || j == "97") {
            h = "已通过";
        } else {
            if (j == "93" || j == "99") {
                if (passenger_id_type_code == "1") {
                    h = "已通过";
                } else {
                    h = "预通过";
                }
            } else {
                if (j == "94" || j == "96") {
                    if (passenger_id_type_code == "1") {
                        h = "未通过";
                    } else {
                        h = "未通过";
                    }
                } else {
                    if (j == "92" || j == "98") {
                        if (passenger_id_type_code == "B" || passenger_id_type_code == "C" || passenger_id_type_code == "G") {
                            h = '请报验';
                        } else {
                            h = '待核验';
                        }
                    } else {
                        if (j == "91") {
                            if (passenger_id_type_code == "B" || passenger_id_type_code == "C" || passenger_id_type_code == "G") {
                                h = '请报验';
                            }
                        } else {
                            h = '请报验';
                        }
                    }
                }
            }
        }
    }
    return h;
}

function paserCacheData(ypinfo, yp_ex) {
    var seatsType = serverCache;
    for (var i = 0; i < seatsType.length; i++) {
        seatTypeMap[seatsType[i].seat_type_code] = seatsType[i].seat_type_name;
    }
    return processYpInfo(ypinfo, yp_ex);
}

function validateData(ypinfo) {
    var arrayLength = ypinfo.length / 10;
    for (var i = 0, m = 6, n = 10, x = 0, y = 1; i < arrayLength; i++, m = m + 10, n = n + 10, x = x + 10, y = y + 10) {
        if ((parseFloat(ypinfo.substring(y, m), 10) / 10) < 0.1) {
            return '0';
        }
    }
    return '1';
}

var deviceModels = new Array("Galaxy Nexus", "samsung GT-I9001", "MOT MT788", "samsung GT-I9508");

function getDeviceModel() {
    var rand = parseInt(Math.random() * deviceModels.length);
    return deviceModels[rand];
}

var seatTypeMap = new Array();
var serverCache = [
    {
        "seat_type_name" : "棚车",
        "seat_type_code" : "0"
    },
    {
        "seat_type_name" : "硬座",
        "seat_type_code" : "1"
    },
    {
        "seat_type_name" : "软座",
        "seat_type_code" : "2"
    },
    {
        "seat_type_name" : "硬卧",
        "seat_type_code" : "3"
    },
    {
        "seat_type_name" : "软卧",
        "seat_type_code" : "4"
    },
    {
        "seat_type_name" : "包厢硬卧",
        "seat_type_code" : "5"
    },
    {
        "seat_type_name" : "高级软卧",
        "seat_type_code" : "6"
    },
    {
        "seat_type_name" : "一等软座",
        "seat_type_code" : "7"
    },
    {
        "seat_type_name" : "二等软座",
        "seat_type_code" : "8"
    },
    {
        "seat_type_name" : "商务座",
        "seat_type_code" : "9"
    },
    {
        "seat_type_name" : "高级动卧",
        "seat_type_code" : "A"
    },
    {
        "seat_type_name" : "混编硬座",
        "seat_type_code" : "B"
    },
    {
        "seat_type_name" : "混编硬卧",
        "seat_type_code" : "C"
    },
    {
        "seat_type_name" : "包厢软座",
        "seat_type_code" : "D"
    },
    {
        "seat_type_name" : "特等软座",
        "seat_type_code" : "E"
    },
    {
        "seat_type_name" : "动卧",
        "seat_type_code" : "F"
    },
    {
        "seat_type_name" : "二人软包",
        "seat_type_code" : "G"
    },
    {
        "seat_type_name" : "一人软包",
        "seat_type_code" : "H"
    },
    {
        "seat_type_name" : "一等双软",
        "seat_type_code" : "I"
    },
    {
        "seat_type_name" : "二等双软",
        "seat_type_code" : "J"
    },
    {
        "seat_type_name" : "混编软座",
        "seat_type_code" : "K"
    },
    {
        "seat_type_name" : "混编软卧",
        "seat_type_code" : "L"
    },
    {
        "seat_type_name" : "一等座",
        "seat_type_code" : "M"
    },
    {
        "seat_type_name" : "二等座",
        "seat_type_code" : "O"
    },
    {
        "seat_type_name" : "特等座",
        "seat_type_code" : "P"
    },
    {
        "seat_type_name" : "观光座",
        "seat_type_code" : "Q"
    },
    {
        "seat_type_name" : "一等包座",
        "seat_type_code" : "S"
    }
];
var seatTypeRateMap = {
    "0" : 41,
    "1" : 23,
    "2" : 22,
    "3" : 21,
    "4" : 20,
    "5" : 40,
    "6" : 18,
    "7" : 24,
    "8" : 25,
    "9" : 10,
    "A" : 26,
    "B" : 27,
    "C" : 28,
    "D" : 29,
    "E" : 30,
    "F" : 31,
    "G" : 32,
    "H" : 33,
    "I" : 34,
    "J" : 35,
    "K" : 36,
    "L" : 37,
    "M" : 14,
    "O" : 16,
    "P" : 12,
    "Q" : 38,
    "S" : 39
};

function processYpInfo(ypinfo, yp_ex) {
    var arrayLength = ypinfo.length / 10;
    var obj = new Array();
    var temp_seat_rate = 50; // 对于没有定义的座位，rate值从50开始递增
    for (var i = 0, m = 6, n = 10, x = 0, y = 1; i < arrayLength; i++, m = m + 10, n = n + 10, x = x + 10, y = y + 10) {
        var seat_type_id = ypinfo.substring(x, y);
        var seat_type = null;
        var seat_type_rate = null;
        var seat_num = 0;
        if (parseInt(ypinfo.substring(m, m + 1), 10) >= 3) {
            seat_type = "无座";
            seat_type_rate = 100;
            seat_num = parseInt(ypinfo.substring(m, n), 10) - 3000;
        } else {
            seat_type = seatTypeMap[seat_type_id];
            seat_type_rate = seatTypeRateMap[seat_type_id];
            if (seat_type_rate === null || seat_type_rate === "undefined") {
                seat_type_rate = temp_seat_rate;
                temp_seat_rate = temp_seat_rate + 1;
            }
            seat_num = parseInt(ypinfo.substring(m, n), 10);
        }

        obj[i] = {
            type_id : seat_type_id,
            type : seat_type,
            type_rate : seat_type_rate, // 保存座位rate用于排序
            num : seat_num,
            uclass : getLiClass(i),
            price : (parseFloat(ypinfo.substring(y, m), 10) / 10)
                .toFixed(2)
        };
    }
    processYpEx(obj, yp_ex);
    var sortedObjs = sortYpInfo(obj);

    for (var i = 0; i < sortedObjs.length; i++) {
        sortedObjs[i].uclass = getLiClass(i);
    }

    //sortedObjs = repalceYpInfoType(sortedObjs);
    return json2str(sortedObjs);
}

function processYpEx(yplist, yp_ex) {
    //席别折扣判断
    for(var k=0;k<yplist.length;k++){
        yplist[k].discount = "0";
        if (yp_ex&&yp_ex.length > 0) {
            for(var di = 0;di<yp_ex.length;di=di+2){
                if(yp_ex.substr(di+1,1) === '1'){
                    if(yp_ex.substr(di,1) == yplist[k].type_id){
                        yplist[k].discount = "1";
                    }
                }
            }
        }else{
            yplist[k].discount = '0';
        }
    }
};

function json2str(o) {
    var arr = [];
    var fmt = function (s) {
        if (typeof s == 'object' && s != null)
            return json2str(s);
        return /^(string|number)$/.test(typeof s) ? "'" + s + "'" : s;
    }
    for (var i in o)
        arr.push("'" + i + "':" + fmt(o[i]));
    return '{' + arr.join(',') + '}';
}

// 按照座位的type_rate进行排序，规则如下
// 商务座、特等座、一等座、二等座、高级软卧、软卧、硬卧、软座、硬座、（...）、无座 的顺序显示；
// 如果出现其余席别，显示在这些席别的后面，顺序暂不限，其中 无座 总放在最后面。
function sortYpInfo(ypinfoArray) {

    var by = function (name) {
        return function (o, p) {
            var a,
                b;
            if (typeof o === "object" && typeof p === "object" && o && p) {
                a = o[name];
                b = p[name];
                if (a === b) {
                    return 0;
                }
                if (typeof a === typeof b) {
                    return a < b ? -1 : 1;
                }
                return typeof a < typeof b ? -1 : 1;
            } else {
                throw("error");
            }
        };
    };

    ypinfoArray.sort(by("type_rate"));
    return ypinfoArray;

}

function getLiClass(index) {
    switch (index % 4) {
        case 0:
            return "ui-block-a";
        case 1:
            return "ui-block-b";
        case 2:
            return "ui-block-c";
        case 3:
            return "ui-block-d";
        default:
            return "ui-block-e";

    }
}

// 把两个字数以上的座位类型改为两位
function repalceYpInfoType(objs) {
    for (var i in objs) {
        var type = objs[i].type;
        switch (type) {
            case "商务座":
                objs[i].type = "商务";
                break;
            case "特等座":
                objs[i].type = "特等";
                break;
            case "一等座":
                objs[i].type = "一等";
                break;
            case "二等座":
                objs[i].type = "二等";
                break;
            case "高级软卧":
                objs[i].type = "高软";
                break;
            case "观光座":
                objs[i].type = "观光";
                break;
        }
    }
    return objs;
};
var Base32 = new function () {
    var delta = 0x9E3779B8;
    function longArrayToString(data, includeLength) {
        var length = data.length;
        var n = (length - 1) << 2;
        if (includeLength) {
            var m = data[length - 1];
            if ((m < n - 3) || (m > n))
                return null;
            n = m;
        }
        for (var i = 0; i < length; i++) {
            data[i] = String.fromCharCode(data[i] & 0xff, data[i] >>> 8 & 0xff, data[i] >>> 16 & 0xff, data[i] >>> 24 & 0xff);
        }
        if (includeLength) {
            return data.join('').substring(0, n);
        } else {
            return data.join('');
        }
    };
    function stringToLongArray(string, includeLength) {
        var length = string.length;
        var result = [];
        for (var i = 0; i < length; i += 4) {
            result[i >> 2] = string.charCodeAt(i) | string.charCodeAt(i + 1) << 8 | string.charCodeAt(i + 2) << 16 | string.charCodeAt(i + 3) << 24;
        }
        if (includeLength) {
            result[result.length] = length;
        }
        return result;
    };
    this.encrypt = function (string, key) {
        if (string == "") {
            return "";
        }
        var v = stringToLongArray(string, true);
        var k = stringToLongArray(key, false);
        if (k.length < 4) {
            k.length = 4;
        }
        var n = v.length - 1;
        var z = v[n],
            y = v[0];
        var mx,
            e,
            p,
            q = Math.floor(6 + 52 / (n + 1)),
            sum = 0;
        while (0 < q--) {
            sum = sum + delta & 0xffffffff;
            e = sum >>> 2 & 3;
            for (p = 0; p < n; p++) {
                y = v[p + 1];
                mx = (z >>> 5^y << 2) + (y >>> 3^z << 4)^(sum^y) + (k[p & 3^e]^z);
                z = v[p] = v[p] + mx & 0xffffffff;
            }
            y = v[0];
            mx = (z >>> 5^y << 2) + (y >>> 3^z << 4)^(sum^y) + (k[p & 3^e]^z);
            z = v[n] = v[n] + mx & 0xffffffff;
        }
        return longArrayToString(v, false);
    };
};

function bin216(s) {
    var i,
        l,
        o = "",
        n;
    s += "";
    b = "";
    for (i = 0, l = s.length; i < l; i++) {
        b = s.charCodeAt(i);
        n = b.toString(16);
        o += n.length < 2 ? "0" + n : n;
    }
    return o;
};

var keyStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
function encode32(input) {
    input = escape(input);
    var output = "";
    var chr1,
        chr2,
        chr3 = "";
    var enc1,
        enc2,
        enc3,
        enc4 = "";
    var i = 0;
    do {
        chr1 = input.charCodeAt(i++);
        chr2 = input.charCodeAt(i++);
        chr3 = input.charCodeAt(i++);
        enc1 = chr1 >> 2;
        enc2 = ((chr1 & 3) << 4) | (chr2 >> 4);
        enc3 = ((chr2 & 15) << 2) | (chr3 >> 6);
        enc4 = chr3 & 63;
        if (isNaN(chr2)) {
            enc3 = enc4 = 64;
        } else if (isNaN(chr3)) {
            enc4 = 64;
        }
        output = output + keyStr.charAt(enc1) + keyStr.charAt(enc2) + keyStr.charAt(enc3) + keyStr.charAt(enc4);
        chr1 = chr2 = chr3 = "";
        enc1 = enc2 = enc3 = enc4 = "";
    } while (i < input.length);
    return output;
};

function loginvalueforkey(key) {
    return encode32(bin216(Base32.encrypt("1111", key)));
};

function cv(rs) {
    var ct = []
    eval('obj = ' + rs)
    //var obj = JSON.parse(rs)
    if(obj.status && obj.data != null && obj.data.length != 0 && obj.data.flag == 1) {
        ct = b2(obj.data.result, obj.data.map)
    }
    // console.log("userAgent =======" + JSON.stringify(ct))
    return JSON.stringify(ct);

}

function b2(data, map) {
    var song = {};
    var co = [];
    for (var cn = 0; cn < data.length; cn++) {
        var cs = {};
        var cm = data[cn].split("|");
        cs.secretHBStr = cm[36];
        cs.secretStr = cm[0];
        cs.buttonTextInfo = cm[1];
        cs.available = cm[0].length > 0;
        var cq = {};
        cq.train_no = cm[2];
        cq.station_train_code = cm[3];
        cq.start_station_telecode = cm[4];
        cq.end_station_telecode = cm[5];
        cq.from_station_telecode = cm[6];
        cq.to_station_telecode = cm[7];
        cq.start_time = cm[8];
        cq.arrive_time = cm[9];
        cq.lishi = cm[10];
        cq.canWebBuy = cm[11];
        cq.yp_info = cm[12];
        cq.start_train_date = cm[13];
        cq.train_seat_feature = cm[14];
        cq.location_code = cm[15];
        cq.from_station_no = cm[16];
        cq.to_station_no = cm[17];
        cq.is_support_card = cm[18];
        cq.controlled_train_flag = cm[19];
        cq.gg_num = cm[20] ? cm[20] : "--";
        cq.gr_num = cm[21] ? cm[21] : "--";
        cq.qt_num = cm[22] ? cm[22] : "--";
        cq.rw_num = cm[23] ? cm[23] : "--";
        cq.rz_num = cm[24] ? cm[24] : "--";
        cq.tz_num = cm[25] ? cm[25] : "--";
        cq.wz_num = cm[26] ? cm[26] : "--";
        cq.yb_num = cm[27] ? cm[27] : "--";
        cq.yw_num = cm[28] ? cm[28] : "--";
        cq.yz_num = cm[29] ? cm[29] : "--";
        cq.ze_num = cm[30] ? cm[30] : "--";
        cq.zy_num = cm[31] ? cm[31] : "--";
        cq.swz_num = cm[32] ? cm[32] : "--";
        cq.srrb_num = cm[33] ? cm[33] : "--";
        cq.yp_ex = cm[34];
        cq.seat_types = cm[34];
        cq.exchange_train_flag = cm[36];
        cq.from_station_name = map[cm[6]];
        cq.start_station_name = map[cm[6]]; //iOS字段不一致，增加这个字段用于抢票单选择车次页展示始发站名
        cq.to_station_name = map[cm[7]];
        cs.queryLeftNewDTO = cq;
        co.push(cs) }
    song.data = co;
    if(android){
        return co;
    }else {
        return song;
    }
}

// var result =
//     cv("{\"data\":{\"flag\":\"1\",\"map\":{\"AOH\":\"上海虹桥\",\"BJP\":\"北京\",\"SHH\":\"上海\",\"VNP\":\"北京南\"},\"result\":[\"|23:00-06:00系统维护时间|240000G1010D|G101|VNP|AOH|VNP|AOH|06:43|12:39|05:56|IS_TIME_NOT_BUY|LGn6dQHxv5qfB8xTat66VnCG1BkMzv5q%2BdduxxrFJY3B2AtD|20180121|3|P2|01|11|1|0|||||||||||有|有|13||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|24000000G503|G5|VNP|AOH|VNP|AOH|07:00|11:34|04:34|IS_TIME_NOT_BUY|%2BTPJ0k6SX2Hh4pYVVuIMQa7SzmKqGLSJhlHrSdEh24hqP88a|20180121|3|P2|01|05|1|0|||||||||||2|无|2||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1050J|G105|VNP|AOH|VNP|AOH|07:35|13:11|05:36|IS_TIME_NOT_BUY|fk88EExRXth17I2CZcTJN1YyAPd3TZxJd%2Bi3ZdXqL0AGScR0|20180121|3|P4|01|09|1|0|||||||||||有|有|9||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|2400000G110I|G11|VNP|AOH|VNP|AOH|08:00|13:06|05:06|IS_TIME_NOT_BUY|0%2F%2BfGDZSKAFkQ0ytPh62IzlIMvF8xOXGw2jAj74igCBFLhoA|20180121|3|P2|01|05|1|0|||||||||||5|有|2||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1070G|G107|VNP|AOH|VNP|AOH|08:05|13:49|05:44|IS_TIME_NOT_BUY|Bv%2FVjrlzxtKVbfWfc0uROeBux1FZL%2BEElETmdwLOl9889yNW|20180121|3|P3|01|09|1|0|||||||||||有|有|19||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|240000G1110W|G111|VNP|AOH|VNP|AOH|08:35|14:22|05:47|IS_TIME_NOT_BUY|iT6%2B7DPCTwNKbnRE9LdZfcY%2B3YvJZNvRBjx1%2BgBFSVbc3X7g|20180121|3|P2|01|09|1|0|||||||||||有|11|1||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1130H|G113|VNP|AOH|VNP|AOH|08:53|14:33|05:40|IS_TIME_NOT_BUY|5mEoF4eg9fjdvzvsAJ6C5YQpCPpamBZbwTMNCWrqDjnz0xEd|20180121|3|P3|01|08|1|0|||||||||||有|有|15||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|24000000G10F|G1|VNP|AOH|VNP|AOH|09:00|13:28|04:28|IS_TIME_NOT_BUY|usY%2BUl57hWKitIUp1d4m3n3e0ys4iJTdDfedKU6oXk7F3bAb|20180121|3|P2|01|04|1|0|||||||||||无|无|无||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|2400000G410J|G41|VNP|HGH|VNP|AOH|09:15|14:49|05:34|IS_TIME_NOT_BUY|P%2FceKrdyFgeMbYBKrjd7WKb2qG5KgcE0vHINKNEIQHmmj2vP|20180121|3|P2|01|08|1|0|||||||||||有|有|5||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1150U|G115|VNP|AOH|VNP|AOH|09:20|15:10|05:50|IS_TIME_NOT_BUY|KyXJG%2FVMKhuNWO4K11KaKjD%2FUj6egKsKcVN0Sqvx1mAiCKuR|20180121|3|P4|01|10|1|0|||||||||||有|有|14||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1170R|G117|VNP|AOH|VNP|AOH|09:25|15:37|06:12|IS_TIME_NOT_BUY|LE0cXD8NRafktr1WWB89kVyVTFXY1bL9fHMy1Y%2FnVQQEPQiV|20180121|3|P3|01|11|1|0|||||||||||有|有|7||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|2400000G1308|G13|VNP|AOH|VNP|AOH|10:00|14:28|04:28|IS_TIME_NOT_BUY|HaT56DkmcWHQ0JdbYg8SMqx1OPW6c0Crz6zMe%2FxLb5qFq67Q|20180121|3|P3|01|04|1|0|||||||||||1|无|3||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1190E|G119|VNP|AOH|VNP|AOH|10:05|15:43|05:38|IS_TIME_NOT_BUY|ZO%2BSYsT92i63g%2FsmWu6aLOE3cbxVny8jjL87CizQnNRZ%2F%2F6O|20180121|3|P4|01|10|1|0|||||||||||无|2|无||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1210I|G121|VNP|AOH|VNP|AOH|10:28|16:32|06:04|IS_TIME_NOT_BUY|usY%2BUl57hWKitIUp1d4m3n3e0ys4iJTdDfedKU6oXk7F3bAb|20180121|3|P2|01|12|1|0|||||||||||无|无|无||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|2400000G150B|G15|VNP|AOH|VNP|AOH|11:00|15:56|04:56|IS_TIME_NOT_BUY|tJBGcF2vqB97r5%2BpsaH9ME7M1luaIZF8vvQ1RoeyRLpDn4I0|20180121|3|P4|01|04|1|0|||||||||||无|3|4||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G12517|G125|VNP|AOH|VNP|AOH|11:10|16:56|05:46|IS_TIME_NOT_BUY|usY%2BUl57hWKitIUp1d4m3n3e0ys4iJTdDfedKU6oXk7F3bAb|20180121|3|P4|01|11|1|0|||||||||||无|无|无||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G41104|G411|VNP|AOH|VNP|AOH|11:20|17:08|05:48|IS_TIME_NOT_BUY|usY%2BUl57hWKitIUp1d4m3n3e0ys4iJTdDfedKU6oXk7F3bAb|20180121|3|P2|01|11|1|0|||||||||||无|无|无||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|24000014611Q|1461|BJP|SHH|BJP|SHH|11:54|07:19|19:25|IS_TIME_NOT_BUY|O3pwHWLI1050rlzHZE4NDh3a9InsdM8TZfWwOQlKcJ01bDg7mzwpOx5e5d0%3D|20180121|3|P2|01|25|0|0||||无|||有||无|有|||||10401030|1413|0\",\"|23:00-06:00系统维护时间|240000G1290P|G129|VNP|AOH|VNP|AOH|12:10|17:56|05:46|IS_TIME_NOT_BUY|iOzBl3czqD6Bjc4nwHTgPc3rMfGpGU2PNDrbZiP%2By4I%2FwGhK|20180121|3|P4|01|11|1|0|||||||||||无|无|1||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1310L|G131|VNP|AOH|VNP|AOH|12:20|18:06|05:46|IS_TIME_NOT_BUY|9NUNuUYEjeDF94azjpb%2F1F2na0yDbt12bx9V1g%2FW%2Fnfs66we|20180121|3|P2|01|10|1|0|||||||||||有|20|无||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|240000G1330G|G133|VNP|AOH|VNP|AOH|12:40|18:33|05:53|IS_TIME_NOT_BUY|EFjkQx8oQhi%2FpGK2ByoOHkdn8%2B8MwzBD%2FMQqfU4uGoP%2BRklF|20180121|3|P3|01|11|1|0|||||||||||无|有|8||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|240000G1350C|G135|VNP|AOH|VNP|AOH|12:55|18:54|05:59|IS_TIME_NOT_BUY|kxXzulK8twdRkbk6X0RveUxb9jnFfiLqe%2FxjRcxhbIOnLq6E|20180121|3|P4|01|11|1|0|||||||||||有|有|17||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|240000G1370N|G137|VNP|AOH|VNP|AOH|13:07|19:04|05:57|IS_TIME_NOT_BUY|wBhfaLCJqhvoBIViQ7cKfWykJLf3rW5C0%2BIyMWqz4X614qkQ|20180121|3|P3|01|11|1|0|||||||||||有|无|4||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1390Q|G139|VNP|AOH|VNP|AOH|13:45|19:48|06:03|IS_TIME_NOT_BUY|aiI4Hhdf5s1GJDMCGjbUO8%2FWtEJpwbgHTeW2Pa4RprQQj1Nr|20180121|3|P4|01|11|1|0|||||||||||有|有|20||O090M0|O9M|1\",\"|23:00-06:00系统维护时间|24000000G309|G3|VNP|AOH|VNP|AOH|14:00|18:28|04:28|IS_TIME_NOT_BUY|usY%2BUl57hWKitIUp1d4m3n3e0ys4iJTdDfedKU6oXk7F3bAb|20180121|3|P3|01|04|1|0|||||||||||无|无|无||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|2400000G4309|G43|VNP|HGH|VNP|AOH|14:05|19:44|05:39|IS_TIME_NOT_BUY|OwWGlKxfnPfPYGOuhjVhioA2r3kj2krs0zxNVD04%2BIDhPhfc|20180121|3|P3|01|09|1|0|||||||||||无|1|无||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1410G|G141|VNP|AOH|VNP|AOH|14:10|20:04|05:54|IS_TIME_NOT_BUY|0B4GiybAta12B73SE%2FI1IDdA6wax6UrEXnL3THf8RPHs%2F%2FKz|20180121|3|P2|01|11|1|0|||||||||||8|有|13||O090M0|O9M|1\",\"|23:00-06:00系统维护时间|240000G1430M|G143|VNP|AOH|VNP|AOH|14:30|20:30|06:00|IS_TIME_NOT_BUY|4ZjIv5klkVPv4eWJfQa7KbtXZaf5W4fpCWQj%2FUykxxIFIuQ%2B|20180121|3|P3|01|11|1|0|||||||||||有|有|11||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|240000G1450O|G145|VNP|AOH|VNP|AOH|14:35|20:47|06:12|IS_TIME_NOT_BUY|NIVE0auGadzNmDDIQ0KfZHDBqqOva7S7wopPDXOQGnMjjJL6|20180121|3|P4|01|12|1|0|||||||||||有|有|20||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|2400000G1709|G17|VNP|AOH|VNP|AOH|15:00|19:28|04:28|IS_TIME_NOT_BUY|L5ysBNF2P4kqPVCZgnps51fkBgT9I9rubLfwnu5EsiQwd%2BJb|20180121|3|P3|01|04|1|0|||||||||||无|无|无||O090M0|O9M|0\",\"|23:00-06:00系统维护时间|240000G1470C|G147|VNP|AOH|VNP|AOH|15:46|21:50|06:04|IS_TIME_NOT_BUY|TWLUW%2FTweIX4s3QGV3r5gKQ4TUukzQWXKtfOhN0hCC4I352A|20180121|3|P3|01|13|1|0|||||||||||有|有|17||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|2400000G2108|G21|VNP|AOH|VNP|AOH|16:00|21:13|05:13|IS_TIME_NOT_BUY|j8jVYjk9ek%2BBzGnJSHlBm4QTsArLEGMz3qOXT0oIE1B5A38M|20180121|3|P2|01|06|1|0|||||||||||无|3|3||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|240000G1512M|G151|VNP|AOH|VNP|AOH|16:35|22:35|06:00|IS_TIME_NOT_BUY|4t61IkYD31qaNeN0csiP54FLSTjRMxn6JPp7WpKHc5YEt9LA|20180121|3|P2|01|12|1|0|||||||||||有|有|有||O0M090|OM9|0\",\"|23:00-06:00系统维护时间|2400000G2302|G23|VNP|AOH|VNP|AOH|17:00|22:39|05:39|IS_TIME_NOT_BUY|AJwEWagAuW6Ywm0klhUt35e3brbSgAkG9OAM0D0VH1oX21qY|20180121|3|P3|01|10|1|0|||||||||||有|有|17||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|240000G1530E|G153|VNP|AOH|VNP|AOH|17:15|22:49|05:34|IS_TIME_NOT_BUY|hLD9LYTFEV2VsnIo19l%2Fwn1qE4Q1SEZrbBOWVQmLVJJyDqV7|20180121|3|P3|01|09|1|0|||||||||||有|有|14||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|240000G1570K|G157|VNP|AOH|VNP|AOH|17:43|23:30|05:47|IS_TIME_NOT_BUY|Fc%2FLMPZNM3WJ14PKWzvZj4UITfvrqDs5%2F0CVYwXhFsIv9%2BXG|20180121|3|P3|01|09|1|0|||||||||||有|有|有||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|24000000G704|G7|VNP|AOH|VNP|AOH|19:00|23:24|04:24|IS_TIME_NOT_BUY|kjVTGFHRW%2FBtbMw%2Faw9W45AGIfquLmUCWlBLk9IG6R1Ru08h|20180121|3|P3|01|04|1|0|||||||||||无|2|2||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|24000000G900|G9|VNP|AOH|VNP|AOH|19:05|23:39|04:34|IS_TIME_NOT_BUY|4kibyJzpdJC%2BxBy455qtG2n9umv3YYLi2PEr5A%2F8d%2FBd10O8|20180121|3|P4|01|05|1|0|||||||||||有|2|5||O0M090|OM9|1\",\"|23:00-06:00系统维护时间|240000T1090X|T109|BJP|SHH|BJP|SHH|19:31|10:43|15:12|IS_TIME_NOT_BUY|E5WjKZL8TpwJn4EpvuzPdjl%2B9EwNKb1054JTIZ%2FpftFCPmdDQdFHhrrlAjPYGINUmnEVpEDH6aw%3D|20180121|3|P4|01|08|0|0||8||无|||有||无|有|||||1040106030|14163|0\",\"|23:00-06:00系统维护时间|240000D3130T|D313|VNP|SHH|VNP|SHH|19:34|07:41|12:07|IS_TIME_NOT_BUY|oOlOjPiNXHwHIN5HHrm00CTseegZiH3R|20180121|3|P3|01|04|0|0||||有|||||||无||||O040|O4|1\",\"|23:00-06:00系统维护时间|240000D3110J|D311|VNP|SHH|VNP|SHH|21:16|09:09|11:53|IS_TIME_NOT_BUY|7INbcGVl%2F1RLx1%2FQT2aTadSlske7swoY|20180121|3|P2|01|04|0|0||||1||||||||||有|F040|F4|1\",\"|23:00-06:00系统维护时间|240000D3210D|D321|VNP|SHH|VNP|SHH|21:23|09:15|11:52|IS_TIME_NOT_BUY|QmgPFFozKxXVzKHv6vCVeZOaUBnKiVw%2F|20180121|3|P2|01|04|0|0||||有|||||||无||||O040|O4|1\"]},\"httpstatus\":200,\"messages\":\"\",\"status\":true}")
// console.log(result);

